-----------------------------------------------------------
-- test_request_db.sql
--
-- Small example site for collecting test case requests.
-- Start page is the service 'showgroups' which lists the
-- test groupings, you can from there generate a new group
-- or click on an existing group for details.
-- The details for a group basically consist of a listing 
-- of the tests with the possibility of clicking tests to 
-- view/edit details or create a new test request.
--
-- To run this sample you also need http_support.sql
-- Setup:
--   dbinit <your_db>.db
--   dbspawn dbsrv9 -xs http <your_db>.db
--   dbisql -jConnect -c "UID=DBA;PWD=SQL;ENG=<your_db>" test_request_db.sql
-- After the script has finished you should be able to 
-- access the site with your browser at the following url:
--   http://localhost/<your_db>/show_groups

-- Clean up in case old DB items exist
--
SET OPTION ON_ERROR='CONTINUE'
go

if exists( select 'a' from sysprocedure where proc_name='show_groups' ) then
	DROP PROCEDURE show_groups; 
end if
go

if exists(select 'a' from SYSWEBSERVICE where service_name='show_groups' ) then
	DROP SERVICE show_groups 
end if
go

if exists( select 'a' from sysprocedure where proc_name='list_group' ) then
	DROP PROCEDURE list_group 
end if
go

if exists(select 'a' from SYSWEBSERVICE where service_name='list_group' ) then
	DROP SERVICE list_group 
end if
go

if exists( select 'a' from sysprocedure where proc_name='add_test_group' ) then
	DROP PROCEDURE add_test_group 
end if
go

if exists(select 'a' from SYSWEBSERVICE where service_name='add_test_group' ) then
	DROP SERVICE add_test_group
end if
go

if exists( select 'a' from sysprocedure where proc_name='show_test' ) then
	DROP PROCEDURE show_test 
end if
go

if exists(select 'a' from SYSWEBSERVICE where service_name='show_test' ) then
	DROP SERVICE show_test 
end if
go

if exists( select 'a' from sysprocedure where proc_name='css' ) then
	DROP PROCEDURE css
end if
go

if exists(select 'a' from SYSWEBSERVICE where service_name='css' ) then
	DROP SERVICE css
end if
go

commit work
go

-- Get support functions
--

--READ http_support.sql
go

-- Create tables
--
CREATE TABLE test_group (
    tg_id INTEGER NOT NULL DEFAULT AUTOINCREMENT,
    tg_name VARCHAR( 128 ),
    PRIMARY KEY ( tg_id )
    )
go

CREATE TABLE test (
    tg_id INTEGER NOT NULL,
    FOREIGN KEY REFERENCES test_group,
    t_id INTEGER DEFAULT AUTOINCREMENT,
    t_description LONG VARCHAR NOT NULL,
    t_result LONG VARCHAR NOT NULL,
    t_comment LONG VARCHAR DEFAULT NULL,
    u_id UNSIGNED INT DEFAULT NULL,
    PRIMARY KEY ( tg_id, t_id )
    )
go

commit work
go

SET OPTION ON_ERROR='PROMPT'
go

-- Create users...
--

-- User for anonymous HTTP access
GRANT connect TO http IDENTIFIED BY 'sqlany'
go

-- Group for test authors
GRANT connect TO authors
go

GRANT group TO authors
go

commit work
go

-- Create Procedures...
--

CREATE PROCEDURE show_groups () RESULT( res LONG VARCHAR )
BEGIN
    DECLARE err_notfound EXCEPTION FOR SQLSTATE '02000';
    DECLARE rslt LONG VARCHAR;
    DECLARE db_name VARCHAR(40);
    DECLARE crlf CHAR(4);
    DECLARE cur_test_group CURSOR FOR
	SELECT '<tr><td><a href="/'|| db_name ||'/list_group?group_id='|| tg.tg_id ||'">'|| tg.tg_name ||'</a></td><td>'|| COUNT(t.tg_id) ||'</td></tr>'|| crlf
	FROM test_group tg LEFT JOIN test t ON (tg.tg_id=t.tg_id)
	GROUP BY t.tg_id,tg.tg_name,tg.tg_id;
    DECLARE line LONG VARCHAR;

    SELECT db_property('Name') INTO db_name;

    SET crlf='\x0d\x0a';
    OPEN cur_test_group;
    SET rslt = '<html>'|| crlf ||'<head>'|| crlf ||'<link rel="stylesheet" href="/' || db_name || '/css" type="text/css">'|| crlf;
    SET rslt = rslt ||'<title>Test Groups</title>'|| crlf || '</head>' || crlf;
    SET rslt = rslt ||'<body>'|| crlf||'<h2>Test Groups</h2>'|| crlf;
    SET rslt = rslt ||'<table>'|| crlf||'<tr><th align="left" width=200>Test Group</th><th align="left" width=150>Number of tests</th></tr>'|| crlf;
    test_group_loop:
    LOOP
	FETCH NEXT cur_test_group into line;
	IF SQLSTATE = err_notfound THEN
	    LEAVE test_group_loop;
	END IF;
	SET rslt = rslt || line;
    END LOOP test_group_loop;
    CLOSE cur_test_group;
    SET rslt = rslt ||'</table>'|| crlf;
    SET rslt = rslt || '<br><hr>' || crlf || '<p><a href="/' || db_name || '/add_test_group">Add new test group</a></p>' || crlf;

    SET rslt = rslt || '</body></html>';

    CALL sa_set_http_header( 'Content-Type', 'text/html' );
    SELECT rslt;
END
go

GRANT execute ON show_groups TO http
go

CREATE SERVICE show_groups TYPE 'RAW' AUTHORIZATION OFF USER http AS call DBA.show_groups()
go

CREATE procedure list_group ( group_id int)
result( res long varchar )
BEGIN
    DECLARE err_notfound EXCEPTION FOR SQLSTATE '02000';
    DECLARE rslt LONG VARCHAR;
    DECLARE group_name LONG VARCHAR;
    DECLARE db_name VARCHAR(40);
    DECLARE crlf CHAR(4);
    DECLARE cur_test_list CURSOR FOR
	    SELECT '<tr><td align="right">'|| t_id ||'</td>'|| crlf ||'<td><a href="/'|| db_name ||'/show_test?group_id=' || group_id || '&test_id=' || t_id || '">' || REPLACE(html_encode(t_description),'\x0d\x0a','<br>') || '</a></td><td>' || t.t_result || '</td><td>'|| IFNULL(t.u_id, 'not assigned',u.user_name) ||'</td></tr>' FROM DBA.test t LEFT OUTER JOIN SYS.SYSUSERPERMS u ON ( t.u_id = u.user_id ) WHERE t.tg_id = group_id;
    DECLARE line LONG VARCHAR;
    SET crlf='\x0d\x0a';
    SELECT tg_name INTO group_name FROM test_group WHERE tg_id = group_id;
    SELECT db_property('Name') INTO db_name;
    OPEN cur_test_list;
    SET rslt = '<html>'|| crlf ||'<head>'|| crlf ||'<link rel="stylesheet" href="/' || db_name || '/css" type="text/css">'|| crlf;
    SET rslt = rslt ||'<title>Test group &quot;' || group_name || '&quot;</title>'|| crlf || '</head>' || crlf;
    SET rslt = rslt ||'<body>' || crlf || '<h2>Test group &quot;' || group_name || '&quot;</h2>' || crlf || '<table>' || crlf || '<tr><th>Test Id</th><th>Description</th><th>Expected result</th><th>Author</th></tr>' || crlf;
    test_list_loop:
    LOOP
	FETCH NEXT cur_test_list into line;
	IF SQLSTATE = err_notfound THEN
	    LEAVE test_list_loop;
	END IF;
	SET rslt = rslt || line || crlf;
    END LOOP test_list_loop;
    CLOSE cur_test_list;
    SET rslt = rslt ||'</table>' || crlf || '<br><hr>' || crlf || '<p>'|| crlf ;
    SET rslt = rslt ||'<a href="/' || db_name || '/show_test?group_id='|| group_id ||'">Add new test</a><br>' || crlf;
    SET rslt = rslt ||'<a href="/' || db_name || '/show_groups">Back to Test Groups</a></p>' || crlf;
    SET rslt = rslt || '</body>' || crlf || '</html>' || crlf;
    CALL sa_set_http_header( 'Content-Type', 'text/html' );
    SELECT rslt;
END
go

GRANT execute ON DBA.list_group TO http
go

CREATE SERVICE list_group TYPE 'RAW' AUTHORIZATION OFF USER http AS call DBA.list_group( :group_id )
go

create procedure add_test_group ( group_name LONG VARCHAR )
result( res long varchar )
BEGIN
    DECLARE err_notfound EXCEPTION FOR SQLSTATE '02000';
    DECLARE group_id INTEGER;
    DECLARE rslt LONG VARCHAR;
    DECLARE db_name VARCHAR(40);
    DECLARE crlf CHAR(4);
    DECLARE line LONG VARCHAR;
    SET crlf='\x0d\x0a';
    SELECT db_property('Name') INTO db_name;
    SET rslt = '<html>' || crlf || '<head>' || crlf ||'<link rel="stylesheet" href="/' || db_name || '/css" type="text/css">'|| crlf;
    IF group_name IS NULL THEN
	SET rslt = rslt ||'<title>Add Test Group</title>'|| crlf ||'</head>' || crlf;
	SET rslt = rslt ||'<body>' || crlf || '<form action="/'|| db_name ||'/add_test_group" method="GET">' || crlf;
	SET rslt = rslt ||'<table class="form">' || crlf || '<tr>' || crlf || '<td class="form"><b>Group Name:</b></td>' || crlf;
	SET rslt = rslt ||'<td class="form"><input name="group_name" type="text" size="64"  class="post"></td>' || crlf || '</tr>' || crlf;
	SET rslt = rslt ||'<tr><td class="form">&nbsp;</td>' || crlf || '<td class="form"><input type="submit" value="Submit" class="button"></td>' || crlf;
	SET rslt = rslt ||'</table>' || crlf || '</form>';
    ELSE
	SET rslt = rslt ||'<title>Creating Test Group ' || group_name || '</title>'|| crlf ||'</head>' || crlf;
	SET rslt = rslt ||'<body>' || crlf;
	SELECT tg_id INTO group_id FROM test_group WHERE tg_name = group_name;
	IF SQLSTATE = err_notfound THEN
	    BEGIN
		INSERT INTO test_group (tg_name) VALUES(group_name);
		SET rslt = rslt ||'<h2>Test Group "' || group_name || '" added</h2>'|| crlf;
	    EXCEPTION
		WHEN OTHERS THEN
		    SET rslt = rslt ||'<h2>Error occured while creating test group "' || group_name || '"</h2>'|| crlf ||'<p>Message:<br>'|| ERRORMSG(SQLSTATE) ||'</p>'|| crlf;
	    END;
	ELSE
	    SET rslt = rslt || '<h2>Test Group "' || group_name || '" already exists</h2>' || crlf;
	END IF;
    END IF;
    SET rslt = rslt || crlf || '<br><hr>' || crlf || '<p><a href="/' || db_name || '/show_groups">Test Groups</a></p>' || crlf || '</body>' || crlf || '</html>';

    CALL sa_set_http_header( 'Content-Type', 'text/html' );
    SELECT rslt;
END
go

GRANT execute ON add_test_group TO authors
go

CREATE SERVICE add_test_group TYPE 'RAW' AUTHORIZATION ON USER authors AS call DBA.add_test_group( :group_name )
go

CREATE procedure show_test ( group_id INTEGER, test_id INTEGER, test_description LONG VARCHAR, test_result LONG VARCHAR, test_author VARCHAR( 128 ), test_comment LONG VARCHAR )
result( res long varchar )
BEGIN
    DECLARE err_notfound EXCEPTION FOR SQLSTATE '02000';
    DECLARE test_uid UNSIGNED INT;
    DECLARE group_name VARCHAR(60);
    DECLARE rslt LONG VARCHAR;
    DECLARE failed BIT;
    DECLARE db_name VARCHAR(40);
    DECLARE crlf CHAR(4);
    DECLARE line LONG VARCHAR;
    DECLARE cnt INTEGER;
    SET crlf='\x0d\x0a';
    SELECT db_property('Name') INTO db_name;
    SET rslt = '<html>' || crlf || '<head>' || crlf ||'<link rel="stylesheet" href="/' || db_name || '/css" type="text/css">'|| crlf;
    
    IF group_id IS NULL THEN
	-- This is an error!
	SET rslt = rslt ||'<title>Error when Adding New Test</title>'|| crlf ||'</head>'|| crlf;
	SET rslt = rslt ||'<body>' || crlf;
	SET rslt = rslt ||'<h2>New Test can only be added if test group is known!</h2>'|| crlf;
	SET rslt = rslt ||'<p>To select a test group click <a href="/' || db_name || '/show_groups">Test Groups</a></p>'|| crlf;
    ELSEIF test_id IS NULL THEN
	-- This means it is either a new test or the form is empty
	SELECT tg_name INTO group_name FROM test_group WHERE tg_id = group_id;
	IF test_description IS NULL OR test_result IS NULL THEN
	    SET rslt = rslt ||'<title>Add New Test to Group "'|| group_name ||'"</title>'|| crlf ||'</head>' || crlf;
	    SET rslt = rslt ||'<body>'|| crlf ||'<h2>Add Test to Group "'|| group_name ||'"</h2>'|| crlf;
	    SET rslt = rslt ||'<form action="/'|| db_name ||'/show_test" method="GET">' || crlf;
	    SET rslt = rslt ||'<input type="hidden" value="'|| group_id ||'" name="group_id">'|| crlf;
	    SET rslt = rslt ||'<table class="form">'|| crlf;
	    SET rslt = rslt ||'<tr>'|| crlf ||'<td class="form"><b>Test Description:</b></td>'|| crlf ||'<td class="form"><textarea name="test_description" cols="50" rows="5" class="post"></textarea></td>'|| crlf ||'</tr>'|| crlf;
	    SET rslt = rslt ||'<tr>'|| crlf ||'<td class="form"><b>Expected Result:</b></td>'|| crlf ||'<td class="form"><textarea name="test_result" cols="50" rows="2" class="post"></textarea></td>'|| crlf ||'</tr>'|| crlf;
	    SET rslt = rslt ||'<tr>'|| crlf ||'<td class="form"><b>Assigned Author (optional):</b></td>'|| crlf ||'<td class="form"><input type="text" name="test_author" size="50" maxlength="128" class="post"></td>'|| crlf ||'</tr>'|| crlf;
	    SET rslt = rslt ||'<tr>'|| crlf ||'<td class="form"><b>Comments (Optional):</b></td>'|| crlf ||'<td class="form"><textarea name="test_comment" cols="50" rows="5" class="post"></textarea></td>'|| crlf ||'</tr>'|| crlf;
	    SET rslt = rslt ||'<tr><td class="form">&nbsp;</td>' || crlf || '<td class="form"><input type="submit" value="Submit" class="button"></td>' || crlf;
	    SET rslt = rslt ||'</table>' || crlf || '</form>';
	ELSE
	    -- We should have enough info to INSERT INTO DB...
	    -- Get  user id if test_author is not NULL
	    SET FAILED = 0;
	    IF test_author IS NOT NULL THEN
		BEGIN
		    SELECT user_id INTO test_uid FROM SYS.SYSUSERPERMS WHERE user_name = test_author;
		EXCEPTION
		    WHEN OTHERS THEN
			SET FAILED = 1;
			SET rslt = rslt ||'<title>Error while adding new test to group "'|| group_name ||'"</title>'|| crlf ||'</head>' || crlf ||'<body>'|| crlf;
			SET rslt = rslt ||'<h2>Error while adding new test to group "'|| group_name ||'"</h2>'|| crlf;
			SET rslt = rslt ||'<p>Could not find user name "'|| test_author ||'".</p><br>'|| crlf;
		END;
	    ELSE
		SET test_uid = NULL;
	    END IF;
	    BEGIN
		INSERT INTO test ( tg_id, t_description, t_result, t_comment, u_id ) VALUES( group_id, test_description, test_result, test_comment, test_uid );
		SET rslt = rslt ||'<title>Adding new test to group "'|| group_name ||'"</title>'|| crlf ||'</head>' || crlf ||'<body>'|| crlf;
		SET rslt = rslt ||'<h2>Successfully added new test to group "'|| group_name ||'".</h2>'|| crlf;
	    EXCEPTION
		WHEN OTHERS THEN
		    IF FAILED = 0 THEN
			SET rslt = rslt ||'<title>Error while adding new test to group "'|| group_name ||'"</title>'|| crlf ||'</head>' || crlf ||'<body>'|| crlf;
			SET rslt = rslt ||'<h2>Error while adding new test to group "'|| group_name ||'"</h2>'|| crlf;
		    END IF;
		    SET FAILED = 1;
		    SET rslt = rslt ||'<p>INSERT failed with this error:<br>'|| crlf || ERRORMSG(SQLSTATE) ||'</p><br>'|| crlf;
	    END;
	END IF;
    ELSE
	SELECT tg_name INTO group_name FROM test_group WHERE tg_id = group_id;

	IF test_description IS NOT NULL AND test_result IS NOT NULL AND length(test_description) > 0 AND length(test_result) > 0 THEN
	    -- Looks like this is an update!
	    -- Check if test exists
	    SELECT COUNT(*) INTO cnt
		FROM test t
		WHERE t.tg_id = group_id AND t.t_id = test_id;
	    IF cnt <> 1 THEN
		-- This means the test is unknown -> INSERT instead of UPDATE
		SET FAILED = 0;
		IF test_author IS NOT NULL THEN
		    BEGIN
			SELECT user_id INTO test_uid FROM SYS.SYSUSERPERMS WHERE user_name = test_author;
		    EXCEPTION
			WHEN OTHERS THEN
			    SET FAILED = 1;
			    SET rslt = rslt ||'<title>Error while adding new test to group "'|| group_name ||'"</title>'|| crlf ||'</head>' || crlf ||'<body>'|| crlf;
			    SET rslt = rslt ||'<h2>Error while adding new test to group "'|| group_name ||'"</h2>'|| crlf;
			    SET rslt = rslt ||'<p>Could not find user name "'|| test_author ||'".</p><br>'|| crlf;
		    END;
		ELSE
		    SET test_uid = NULL;
		END IF;
		BEGIN
		    INSERT INTO test ( tg_id, t_description, t_result, t_comment, u_id ) VALUES( group_id, test_description, test_result, test_comment, test_uid );
		    SET rslt = rslt ||'<title>Adding new test to group "'|| group_name ||'"</title>'|| crlf ||'</head>' || crlf ||'<body>'|| crlf;
		    SET rslt = rslt ||'<h2>Successfully added new test to group "'|| group_name ||'".</h2>'|| crlf;
		EXCEPTION
		    WHEN OTHERS THEN
			IF FAILED = 0 THEN
			    SET rslt = rslt ||'<title>Error while adding new test to group "'|| group_name ||'"</title>'|| crlf ||'</head>' || crlf ||'<body>'|| crlf;
			    SET rslt = rslt ||'<h2>Error while adding new test to group "'|| group_name ||'"</h2>'|| crlf;
			END IF;
			SET FAILED = 1;
			SET rslt = rslt ||'<p>INSERT failed with this error:<br>'|| crlf || ERRORMSG(SQLSTATE) ||'</p><br>'|| crlf;
		END;
	    ELSE
		-- Updating a test...
		SET FAILED = 0;
		IF test_author IS NOT NULL THEN
		    BEGIN
			SELECT user_id INTO test_uid FROM SYS.SYSUSERPERMS WHERE user_name = test_author;
		    EXCEPTION
			WHEN OTHERS THEN
			    SET FAILED = 1;
			    SET rslt = rslt ||'<title>Error while updating test in group "'|| group_name ||'"</title>'|| crlf ||'</head>' || crlf ||'<body>'|| crlf;
			    SET rslt = rslt ||'<h2>Error while updating test (id '||test_id||') in group "'|| group_name ||'"</h2>'|| crlf;
			    SET rslt = rslt ||'<p>Could not find user name "'|| test_author ||'".</p><br>'|| crlf;
		    END;
		ELSE
		    SET test_uid = NULL;
		END IF;
		BEGIN
		    UPDATE test
			SET t_description = test_description, t_result = test_result,
			t_comment = test_comment, u_id = test_uid
			WHERE tg_id = group_id AND t_id = test_id;
		    SET rslt = rslt ||'<title>Updating test in group "'|| group_name ||'"</title>'|| crlf ||'</head>' || crlf ||'<body>'|| crlf;
		    SET rslt = rslt ||'<h2>Successfully updated test (id '||test_id||') in group "'|| group_name ||'".</h2>'|| crlf;
		EXCEPTION
		    WHEN OTHERS THEN
			IF FAILED = 0 THEN
			    SET rslt = rslt ||'<title>Error while updating test in group "'|| group_name ||'"</title>'|| crlf ||'</head>' || crlf ||'<body>'|| crlf;
			    SET rslt = rslt ||'<h2>Error while updating test (id '||test_id||') in group "'|| group_name ||'"</h2>'|| crlf;
			END IF;
			SET FAILED = 1;
			SET rslt = rslt ||'<p>UPDATE failed with this error:<br>'|| crlf || ERRORMSG(SQLSTATE) ||'</p><br>'|| crlf;
		    RESIGNAL;
		END;
	    END IF;
	ELSE
	    SELECT t.t_description, t.t_result, t.t_comment, u.user_name
		INTO test_description, test_result, test_comment, test_author 
		FROM test t LEFT JOIN SYS.SYSUSERPERMS u ON ( t.u_id = u.user_id )
		WHERE t.tg_id = group_id AND t.t_id = test_id;
	    IF SQLSTATE = err_notfound THEN
		SET rslt = rslt || '<h2>Test Group "' || group_name || '" does not feature a test with ID '|| test_id ||'</h2>';
	    ELSE
		SET rslt = rslt ||'<h2>Details of Test in Group "'|| group_name || '"</h2>'|| crlf;
		SET rslt = rslt ||'<form action="/'|| db_name ||'/show_test" method="GET">' || crlf;
		SET rslt = rslt ||'<input type="hidden" value="'|| group_id ||'" name="group_id">'|| crlf;
		SET rslt = rslt ||'<input type="hidden" value="'|| test_id ||'" name="test_id">'|| crlf;
		SET rslt = rslt ||'<table>'|| crlf;
		SET rslt = rslt ||'<tr>'|| crlf ||'<td class="form"><b>Test Description:</b></td>'|| crlf ||'<td class="form"><textarea name="test_description" cols="50" rows="5" class="post">'|| test_description ||'</textarea></td>'|| crlf ||'</tr>'|| crlf;
		SET rslt = rslt ||'<tr>'|| crlf ||'<td class="form"><b>Expected Result:</b></td>'|| crlf ||'<td class="form"><textarea name="test_result" cols="50" rows="2" class="post">'|| test_result ||'</textarea></td>'|| crlf ||'</tr>'|| crlf;
		SET rslt = rslt ||'<tr>'|| crlf ||'<td class="form"><b>Assigned Author (optional):</b></td>'|| crlf ||'<td class="form"><input type="text" name="test_author" size="50" maxlength="128" class="post" value="'|| test_author ||'"></td>'|| crlf ||'</tr>'|| crlf;
		SET rslt = rslt ||'<tr>'|| crlf ||'<td class="form"><b>Comments (Optional):</b></td>'|| crlf ||'<td class="form"><textarea name="test_comment" cols="50" rows="5" class="post">'|| test_comment ||'</textarea></td>'|| crlf ||'</tr>'|| crlf;
		SET rslt = rslt ||'<tr><td class="form">&nbsp;</td>' || crlf || '<td class="form"><input type="submit" value="Submit" class="button"></td>' || crlf;
		SET rslt = rslt ||'</table>' || crlf || '</form>';
	    END IF;
	END IF;
    END IF;
    SET rslt = rslt || crlf || '<br><hr>' || crlf || '<p><a href="/' || db_name || '/list_group?group_id='|| group_id ||'">Back to Test Group "'|| group_name ||'"</a></p>' || crlf || '</body>' || crlf || '</html>';

    CALL sa_set_http_header( 'Content-Type', 'text/html' );
    SELECT rslt;
END
go

GRANT execute ON show_test TO authors, http
go

CREATE SERVICE show_test TYPE 'RAW' AUTHORIZATION ON USER authors AS call DBA.show_test( :group_id, :test_id, :test_description, :test_result, :test_author, :test_comment )
go

CREATE procedure css ( )
result( res long varchar )
BEGIN
    DECLARE rslt LONG VARCHAR;
    DECLARE crlf CHAR(4);
    SET crlf='\x0d\x0a';
    SET rslt = 'body {'|| crlf ||'background-color: #330066;'|| crlf ||'color: #DD7700;'|| crlf ||'scrollbar-face-color: #552288;'|| crlf;
    SET rslt = rslt ||'scrollbar-highlight-color: #552288;'|| crlf ||'scrollbar-shadow-color: #552288;'|| crlf ||'scrollbar-3dlight-color: #663399;'|| crlf;
    SET rslt = rslt ||'scrollbar-arrow-color:  #CC6600;'|| crlf ||'scrollbar-track-color: #441177;'|| crlf ||'scrollbar-darkshadow-color: #330066; }'|| crlf;
    SET rslt = rslt ||'font,th,td,p,a { font-family: Verdana, Arial, Helvetica, sans-serif; }'|| crlf;
    SET rslt = rslt ||'p, td { font-size: 13px; }'|| crlf;
    SET rslt = rslt ||'a:link,a:active,a:visited { text-decoration: none; color : #DD7700; }'|| crlf;
    SET rslt = rslt ||'a:hover		{ text-decoration: none; color : #FF9900; }'|| crlf;
    SET rslt = rslt ||'h1,h2 {'|| crlf ||'font-weight: bold; font-size: 22px; font-family: "Trebuchet MS", Verdana, Arial, Helvetica, sans-serif;'|| crlf || 'text-decoration: none; line-height : 120%; color : #DD7700; }'|| crlf;
    SET rslt = rslt ||'input,textarea,select {'|| crlf ||'color : #DD7700;'|| crlf ||'font: normal 12px Verdana, Arial, Helvetica, sans-serif;'|| crlf ||'border-color : #7744AA; }'|| crlf;
    SET rslt = rslt ||'input.post, textarea.post {'|| crlf ||'background-color : #330066; }'|| crlf;
    SET rslt = rslt ||'select {'|| crlf ||'background-color : #330066; }'|| crlf;
    SET rslt = rslt ||'input { text-indent : 2px; }'|| crlf;
    SET rslt = rslt ||'input.button {'|| crlf ||'background-color : #330066;'|| crlf ||'color : #DD7700;'|| crlf ||'font-size: 11px; font-family: Verdana, Arial, Helvetica, sans-serif; }'|| crlf;
    SET rslt = rslt ||'hr { color : #DD7700; }'|| crlf;
    SET rslt = rslt ||'table { padding:0px; spacing: 2px; border:0px; background: #330066; }'|| crlf;
    SET rslt = rslt ||'td { padding:5px; border: 1px solid #FF9900; border-right:1px solid #CC6600; border-bottom:1px solid #CC6600; background: #330066; }'|| crlf;
    SET rslt = rslt ||'th { padding:5px; border: 0px solid #FF9900; border-right:1px solid #CC6600; border-bottom:1px solid #CC6600; background: #CC6600; color: #330066; }'|| crlf;
    SET rslt = rslt ||'table.form,td.form { padding: 3px; spacing: 2px; border: 0px; background: #330066; }'|| crlf;

    CALL sa_set_http_header( 'Content-Type', 'text/html' );
    SELECT rslt;
END
go

GRANT execute ON css TO http
go

CREATE SERVICE css TYPE 'RAW' AUTHORIZATION OFF USER http AS call DBA.css()
go

commit work
go

